<?php

/* WooCommerce Integration */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

add_action( 'woocommerce_before_main_content', 'interico_wrapper_start', 10 );
add_action( 'woocommerce_after_main_content', 'interico_wrapper_end', 10 );

function interico_wrapper_start() {

	$page_for_shop = (int)get_option( 'woocommerce_shop_page_id' );

	if ( class_exists( 'acf' ) && is_active_sidebar( 'shop-sidebar' ) ) {
		$sidebar_position = get_field( 'sidebar_position', $page_for_shop );
		if ( ! $sidebar_position ) {
			$sidebar_position = 'right';
		}
	}  elseif ( is_active_sidebar( 'shop-sidebar' ) ) {
		$sidebar_position = 'right';
	} else {
		$sidebar_position = 'disabled';
	}
	$sidebar_position = strtolower( $sidebar_position);

	get_template_part( 'template-parts/top-content-area' );
	?>
		
	<div class="content">
		<div class="container">
			<div class="row">
				<main class="col-xs-12 <?php echo esc_attr( $sidebar_position === 'left' ? 'col-md-9 col-md-push-3' : '' ); echo esc_attr( $sidebar_position === 'right' ? 'col-md-9' : '' ); ?>">
	<?php
}

function interico_wrapper_end() {

	// Get Sidebar position set via Customizer
	$page_for_shop = (int)get_option( 'woocommerce_shop_page_id' );

	if ( class_exists( 'acf' ) && is_active_sidebar( 'shop-sidebar' ) ) {
		$sidebar_position = get_field( 'sidebar_position', $page_for_shop );
		if ( ! $sidebar_position ) {
			$sidebar_position = 'right';
		}
	}  elseif ( is_active_sidebar( 'shop-sidebar' ) ) {
		$sidebar_position = 'right';
	} else {
		$sidebar_position = 'disabled';
	}
	$sidebar_position = strtolower( $sidebar_position);

	?>
				</main>
		
				<?php if ( 'disabled' !== $sidebar_position && is_active_sidebar( 'shop-sidebar' ) ) : ?>
					<div class="col-xs-12 col-md-3 <?php echo esc_attr( $sidebar_position === 'left' ? ' col-md-pull-9' : '' ); ?>">
						<aside class="sidebar-nav">
							<?php dynamic_sidebar( 'shop-sidebar' ); ?>
						</aside>
					</div>
				<?php endif ?>

			</div>
		</div>
	</div>
	<?php
}
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

/**
 * Remove WooCommerce title as we are showing our default title
 */
add_filter( 'woocommerce_show_page_title', '__return_false' );

/**
 * Set our own sidebar option
 */
add_filter( 'woocommerce_get_sidebar', '__return_false' );

/**
 * Set number of products per page to 24 or custom value
 */
function interico_shop_products_number() {
	$items_per_page = get_theme_mod( 'tc_shop_items_per_page');

	// Set default number of items per page
	if( ! $items_per_page ) { 
		$items_per_page = 24;
	}

	return $items_per_page;
}
add_filter( 'loop_shop_per_page', 'interico_shop_products_number', 24 );

/**
 *  Set number of products per row to 3 or custom value
 */
if ( !function_exists( 'interico_loop_columns' ) ) {
	function interico_loop_columns() {

		$items_per_row = get_theme_mod( 'tc_shop_products_columns' );

		// Set default number of columns
		if( ! $items_per_row ) { 
			$items_per_row = 3;
		}

		return $items_per_row; // 3 products per row
	}
}
add_filter( 'loop_shop_columns', 'interico_loop_columns' );

/**
 * The position of the sidebar for shop pages
 */
function interico_shop_sidebar() {
	if ( is_woocommerce() ) {
			
		if ( class_exists( 'acf' ) && is_active_sidebar( 'shop-sidebar' ) ) {
			// Get the Shop sidebar position set for the WooCommerce page
			$sidebar_position = get_field( 'sidebar_position', (int)get_option( 'woocommerce_shop_page_id' ) );
			if ( ! $sidebar_position ) {
				$sidebar_position = 'right';
			}
		} elseif ( is_active_sidebar( 'shop-sidebar' ) ) {
			// Set default position to Right
			$sidebar_position = 'right';
		} else {
			$sidebar_position = 'disabled';
		}
		$sidebar_position = strtolower( $sidebar_position);
		
		// Return the sidebar
		return $sidebar_position;
	}
}

/**
 * Set the amount of related products shown at the bottom on product pages
 */
function interico_related_products( $args ) {
	// 3 related products
	$args['posts_per_page'] = 3;
	// arranged in columns
	$args['columns'] = 3;

	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'interico_related_products' );

// Adds custom button value for products in category: sample
add_filter( 'woocommerce_product_single_add_to_cart_text', 'interico_product_cat_single_add_to_cart_button_text', 20, 1 );
function interico_product_cat_single_add_to_cart_button_text( $text ) {
    // Only for a specific product category
    if( has_term( array( 'sample' ), 'product_cat' ) )
        $text = __( 'Free Sample', 'interico' );

    return $text;
}

// Custom Add to Cart button text
add_filter('single_add_to_cart_text', 'interico_custom_cart_button_text');

function interico_custom_cart_button_text() {

	$add_to_cart_text = get_theme_mod( 'tc_shop_add_to_cart', 'Add to Cart' );

	return sprintf( esc_html__( '%s', 'interico' ), $add_to_cart_text );
}